==> minter-android-explorer-testnet-0.6.3-sources.jar: network/minter/explorer/repo/ExplorerValidatorsRepository.java <==
/*
 * Copyright (C) by MinterTeam. 2019
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.explorer.repo;

import java.util.List;

import javax.annotation.Nonnull;

import network.minter.core.internal.api.ApiService;
import network.minter.core.internal.data.DataRepository;
import network.minter.explorer.api.ExplorerValidatorsEndpoint;
import network.minter.explorer.models.ExpResult;
import network.minter.explorer.models.ValidatorItem;
import retrofit2.Call;

/**
 * minter-android-explorer. 2019
 * @author Eduard Maximovich [edward.vstock@gmail.com]
 */
public class ExplorerValidatorsRepository extends DataRepository<ExplorerValidatorsEndpoint> {
    public ExplorerValidatorsRepository(@Nonnull ApiService.Builder apiBuilder) {
        super(apiBuilder);
    }

    /**
     * Get list of validators with full information about them
     * @return Retrofit call
     */
    public Call<ExpResult<List<ValidatorItem>>> getValidators() {
        return getInstantService().getValidators();
    }

    @Nonnull
    @Override
    protected Class<ExplorerValidatorsEndpoint> getServiceClass() {
        return ExplorerValidatorsEndpoint.class;
    }
}

==> minter-android-explorer-testnet-0.8.0-sources.jar: network/minter/explorer/repo/ExplorerValidatorsRepository.java <==
/*
 * Copyright (C) by MinterTeam. 2020
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.explorer.repo;

import java.util.List;

import javax.annotation.Nonnull;

import network.minter.core.internal.api.ApiService;
import network.minter.core.internal.data.DataRepository;
import network.minter.explorer.api.ExplorerValidatorsEndpoint;
import network.minter.explorer.api.converters.ExplorerValidatorsDeserializer;
import network.minter.explorer.models.ExpResult;
import network.minter.explorer.models.ValidatorItem;
import retrofit2.Call;

/**
 * minter-android-explorer. 2019
 *
 * @author Eduard Maximovich [edward.vstock@gmail.com]
 */
public class ExplorerValidatorsRepository extends DataRepository<ExplorerValidatorsEndpoint> implements DataRepository.Configurator {
    public ExplorerValidatorsRepository(@Nonnull ApiService.Builder apiBuilder) {
        super(apiBuilder);
    }

    /**
     * Get list of validators with full information about them
     *
     * @return Retrofit call
     */
    public Call<ExpResult<List<ValidatorItem>>> getValidators() {
        return getInstantService().getValidators();
    }

    @Nonnull
    @Override
    protected Class<ExplorerValidatorsEndpoint> getServiceClass() {
        return ExplorerValidatorsEndpoint.class;
    }


    @Override
    public void configure(ApiService.Builder api) {
        api.registerTypeAdapter(ValidatorItem.class, new ExplorerValidatorsDeserializer());
    }
}
